==> syd-3.40.1.tar.gz: syd-v3.40.1/src/utils/syd-stat.rs <==
//
// Syd: rock-solid application kernel
// src/utils/syd-stat.rs: Print process status of the given PID or the current process.
//
// Copyright (c) 2024, 2025 Ali Polatel <alip@chesswob.org>
//
// SPDX-License-Identifier: GPL-3.0

use std::process::ExitCode;

use nix::{libc::pid_t, unistd::Pid};
use serde_json::json;
use syd::proc::{proc_stat, proc_status};

// Set global allocator to mimalloc.
#[cfg(all(not(feature = "prof"), target_pointer_width = "64"))]
#[global_allocator]
static GLOBAL: mimalloc::MiMalloc = mimalloc::MiMalloc;

// Set global allocator to tcmalloc if profiling is enabled.
#[cfg(feature = "prof")]
#[global_allocator]
static GLOBAL: tcmalloc::TCMalloc = tcmalloc::TCMalloc;

syd::main! {
    syd::set_sigpipe_dfl()?;

    // Configure syd::proc.
    syd::config::proc_init()?;

    let pid = match std::env::args().nth(1).map(|arg| arg.parse::<pid_t>()) {
        Some(Ok(pid)) => pid,
        None => Pid::this().as_raw(),
        Some(Err(_)) => {
            help();
            return Ok(ExitCode::SUCCESS);
        }
    };

    let stat = proc_stat(Pid::from_raw(pid))?;
    let status = proc_status(Pid::from_raw(pid))?;
    #[expect(clippy::disallowed_methods)]
    let status = json!({
        "pid": pid,
        "tgid": status.pid,
        "command": status.command,
        "umask": status.umask,
        "tty_nr": stat.tty_nr,
        "startstack": stat.startstack,
        "num_threads": stat.num_threads,
        "sig": {
            "blocked": status.sig_blocked,
            "caught": status.sig_caught,
            "ignored": status.sig_ignored,
            "pending_thread": status.sig_pending_thread,
            "pending_process": status.sig_pending_process,
        },
    });

    #[expect(clippy::disallowed_methods)]
    let status = serde_json::to_string(&status).expect("JSON");
    println!("{status}");

    Ok(ExitCode::SUCCESS)
}

fn help() {
    println!("Usage: syd-stat [PID]");
    println!("Print detailed information about the given process process or current process.");
}

==> syd-3.43.0.tar.gz: syd-v3.43.0/src/utils/syd-stat.rs <==
//
// Syd: rock-solid application kernel
// src/utils/syd-stat.rs: Print process status of the given PID or the current process.
//
// Copyright (c) 2024, 2025 Ali Polatel <alip@chesswob.org>
//
// SPDX-License-Identifier: GPL-3.0

use std::{
    io::{stdout, Write},
    process::ExitCode,
};

use nix::{libc::pid_t, unistd::Pid};
use serde_json::json;
use syd::proc::{proc_stat, proc_status};

// Set global allocator to mimalloc.
#[cfg(all(not(feature = "prof"), target_pointer_width = "64"))]
#[global_allocator]
static GLOBAL: mimalloc::MiMalloc = mimalloc::MiMalloc;

// Set global allocator to tcmalloc if profiling is enabled.
#[cfg(feature = "prof")]
#[global_allocator]
static GLOBAL: tcmalloc::TCMalloc = tcmalloc::TCMalloc;

syd::main! {
    syd::set_sigpipe_dfl()?;

    // Configure syd::proc.
    syd::config::proc_init_simple()?;

    let pid = match std::env::args().nth(1).map(|arg| arg.parse::<pid_t>()) {
        Some(Ok(pid)) => pid,
        None => Pid::this().as_raw(),
        Some(Err(_)) => {
            help();
            return Ok(ExitCode::SUCCESS);
        }
    };

    let stat = proc_stat(Pid::from_raw(pid))?;
    let status = proc_status(Pid::from_raw(pid))?;
    #[expect(clippy::disallowed_methods)]
    let status = json!({
        "pid": pid,
        "tgid": status.pid,
        "command": status.command,
        "umask": status.umask,
        "tty_nr": stat.tty_nr,
        "startstack": stat.startstack,
        "num_threads": stat.num_threads,
        "sig": {
            "blocked": status.sig_blocked,
            "caught": status.sig_caught,
            "ignored": status.sig_ignored,
            "pending_thread": status.sig_pending_thread,
            "pending_process": status.sig_pending_process,
        },
    });

    #[expect(clippy::disallowed_methods)]
    let mut status = serde_json::to_string(&status).expect("JSON");
    status.push('\n');
    stdout().write_all(status.as_bytes())?;

    Ok(ExitCode::SUCCESS)
}

fn help() {
    println!("Usage: syd-stat [PID]");
    println!("Print detailed information about the given process process or current process.");
}
